==> morbig_0.10.4.orig.tar.xz: morbig-0.10.4/src/morbig.ml <==
(**************************************************************************)
(*  -*- tuareg -*-                                                        *)
(*                                                                        *)
(*  Copyright (C) 2017,2018,2019 Yann Régis-Gianas, Nicolas Jeannerod,    *)
(*  Ralf Treinen.                                                         *)
(*                                                                        *)
(*  This is free software: you can redistribute it and/or modify it       *)
(*  under the terms of the GNU General Public License, version 3.         *)
(*                                                                        *)
(*  Additional terms apply, due to the reproduction of portions of        *)
(*  the POSIX standard. Please refer to the file COPYING for details.     *)
(**************************************************************************)

(** {2 Main API points} *)

include API

(** {2 Other modules} *)

module Aliases = Aliases
module Assignment = Assignment
module CSTHelpers = CSTHelpers
module CST = CST
module Debug = Debug
module Engine = Engine
module Errors = Errors
module ExtMenhirLib = ExtMenhirLib
module HereDocument = HereDocument
module JsonHelpers = JsonHelpers
module Keyword = Keyword
module Name = Name
module Nesting = Nesting
module Options = Options
module Parser = Parser
module Prelexer = Prelexer
module PrelexerState = PrelexerState
module Pretokenizer = Pretokenizer
module Pretoken = Pretoken
module QuoteRemoval = QuoteRemoval
module RecursiveParser = RecursiveParser
module Scripts = Scripts
module Token = Token

==> morbig_0.11.0.orig.tar.xz: morbig-0.11.0/src/morbig.ml <==
(**************************************************************************)
(*  Copyright (C) 2017-2023 Yann Régis-Gianas, Nicolas Jeannerod,         *)
(*  Ralf Treinen.                                                         *)
(*                                                                        *)
(*  This is free software: you can redistribute it and/or modify it       *)
(*  under the terms of the GNU General Public License, version 3.         *)
(*                                                                        *)
(*  Additional terms apply, due to the reproduction of portions of        *)
(*  the POSIX standard. Please refer to the file COPYING for details.     *)
(**************************************************************************)

(** {2 Main API points} *)

include API

(** {2 Other modules} *)

module Aliases = Aliases
module Assignment = Assignment
module CSTHelpers = CSTHelpers
module CST = CST
module CSTSerializers = CSTSerializers
module CSTVisitors = CSTVisitors
module Debug = Debug
module Engine = Engine
module Errors = Errors
module ExtMenhirLib = ExtMenhirLib
module HereDocument = HereDocument
module JsonHelpers = JsonHelpers
module Keyword = Keyword
module Name = Name
module Nesting = Nesting
module Options = Options
module Parser = Parser
module Prelexer = Prelexer
module PrelexerState = PrelexerState
module Pretokenizer = Pretokenizer
module Pretoken = Pretoken
module QuoteRemoval = QuoteRemoval
module RecursiveParser = RecursiveParser
module Scripts = Scripts
module Token = Token
